#!/usr/bin/python

import sys
import codecs

# Usage: python [this script] [original CTB5 file] [reannotation dic file] > [reannotated CTB5 file]
def main():
    sys.stdin = codecs.getreader('utf-8')(sys.stdin)
    sys.stdout = codecs.getwriter('utf-8')(sys.stdout)
    sys.stderr = codecs.getwriter('utf-8')(sys.stderr)
    targetName = sys.argv[1]
    goldName = sys.argv[2]
    targetFileHandle = codecs.open(targetName, 'rU', 'utf-8')
    goldFileHandle = codecs.open(goldName, 'rU', 'utf-8')
    reannotatedList = []
    loadMap(reannotatedList, goldFileHandle)
    loadCTB(reannotatedList, targetFileHandle)

def loadMap(reannotatedList, goldFileHandle):
    for line in goldFileHandle:
        if not line.startswith('#'):
            ll = line.strip()
            reannotatedList.append(ll)

def loadCTB(reannotatedList, targetFileHandle):
    ss = 0
    for line in targetFileHandle:
        if line.startswith('#'):
            sys.stdout.write(line)
        else:
            rawSentence = ''
            ll = line.strip()
            pairs = ll.split(' ')
            for onePair in pairs:
                word_pos = onePair.split('_')
                assert len(word_pos) == 2
                rawSentence += word_pos[0]
            assert ss < len(reannotatedList)
            dicPairs = reannotatedList[ss].split(' ')
            indices_pos = dicPairs[-1].split('_')
            assert len(indices_pos) == 2
            indices = indices_pos[0].split(',')
            assert len(indices) == 2
            if not int(indices[1]) == len(rawSentence):
                sys.stderr.write('Sentence length does not match its reannotated version, skipped:\n')
                sys.stderr.write(rawSentence + '\n')
                ss += 1
                continue
            for ii in xrange(0, len(dicPairs)):
                indices_pos = dicPairs[ii].split('_')
                assert len(indices_pos) == 2
                indices = indices_pos[0].split(',')
                assert len(indices) == 2
                if ii > 0:
                    sys.stdout.write(' ')
                sys.stdout.write(rawSentence[int(indices[0]):int(indices[1])] + '_' + indices_pos[1])
            sys.stdout.write('\n')
            ss += 1

if __name__ == '__main__':
    main()
